@@ -32,6 +32,8 @@
  * $Author: chrisc $
  *******************************************************************************/
 
+#include <cstdlib>
+
 #include <ctype.h>
 #include <boost/date_time/posix_time/posix_time.hpp>
 
@@ -699,7 +701,7 @@ void Parser::Parse_Num_Factor (EXPRESS Express,int *Terms)
 				case VAL_TOKEN:
 					GET (LEFT_PAREN_TOKEN);
 					Local_C_String=Parse_C_String();
-					Val = atof(Local_C_String);
+					Val = std::atof(Local_C_String);
 					POV_FREE(Local_C_String);
 					GET (RIGHT_PAREN_TOKEN);
 					break;
@@ -1528,7 +1530,7 @@ void Parser::Parse_Num_Factor (EXPRESS Express,int *Terms)
 
 void Parser::Promote_Express(EXPRESS Express,int *Old_Terms,int New_Terms)
 {
-	register int i;
+	int i;
 
 	if (*Old_Terms >= New_Terms)
 		return;
@@ -1576,7 +1578,7 @@ void Parser::Promote_Express(EXPRESS Express,int *Old_Terms,int New_Terms)
 
 void Parser::Parse_Num_Term (EXPRESS Express,int *Terms)
 {
-	register int i;
+	int i;
 	EXPRESS Local_Express;
 	int Local_Terms;
 
@@ -1649,7 +1651,7 @@ void Parser::Parse_Num_Term (EXPRESS Express,int *Terms)
 
 void Parser::Parse_Rel_Factor (EXPRESS Express,int *Terms)
 {
-	register int i;
+	int i;
 	EXPRESS Local_Express;
 	int Local_Terms;
 
@@ -1802,7 +1804,7 @@ void Parser::Parse_Rel_String_Term (const UCS2* lhs, EXPRESS Express, int Terms)
 
 void Parser::Parse_Rel_Term (EXPRESS Express,int *Terms)
 {
-	register int i;
+	int i;
 	EXPRESS Local_Express;
 	int Local_Terms;
 
@@ -1902,7 +1904,7 @@ void Parser::Parse_Rel_Term (EXPRESS Express,int *Terms)
 
 void Parser::Parse_Logical (EXPRESS Express,int *Terms)
 {
-	register int i;
+	int i;
 	EXPRESS Local_Express;
 	int Local_Terms;
 
@@ -2394,7 +2396,7 @@ void Parser::Parse_Colour (COLOUR colour, bool expectFT)
 {
 	EXPRESS Express;
 	int Terms;
-	register int i;
+	int i;
 	bool old_allow_id = Allow_Identifier_In_Call;
 	Allow_Identifier_In_Call = false;
 
