@@ -30,6 +30,7 @@
  *******************************************************************************/
 
 #include <cctype>
+#include <cstdlib>
 
 // configbase.h must always be the first POV file included within base *.cpp files
 #include "base/configbase.h"
@@ -460,7 +461,7 @@ int ProcessRenderOptions::ReadSpecialOptionHandler(INI_Parser_Table *option, cha
 						err = POVMSUtil_SetString(&decobj, kPOVAttrib_Value, ptr);
 					}
 					else
-						err = POVMSUtil_SetFloat(&decobj, kPOVAttrib_Value, atof(ptr));
+						err = POVMSUtil_SetFloat(&decobj, kPOVAttrib_Value, std::atof(ptr));
 				}
 				if(err == kNoErr)
 					err = POVMSAttrList_Append(&list, &decobj);
@@ -513,7 +514,7 @@ int ProcessRenderOptions::ReadSpecialOptionHandler(INI_Parser_Table *option, cha
 				case kPOVAttrib_DisplayGamma:    typeKey = kPOVAttrib_DisplayGammaType;      break;
 				case kPOVAttrib_FileGamma:       typeKey = kPOVAttrib_FileGammaType;         break;
 			}
-			floatval = atof(param);
+			floatval = std::atof(param);
 			if (floatval == 1.0)
 				intval = kPOVList_GammaType_Neutral;
 			else if (floatval > 0)
